@@ -9,12 +9,14 @@ pub mod tool_use;
 
 pub use context::{AgentContext, ContextId, ContextLoadResult};
 pub use context_store::ContextStore;
+use fs::Fs;
+use std::sync::Arc;
 pub use thread::{
     LastRestoreCheckpoint, Message, MessageCrease, MessageId, MessageSegment, Thread, ThreadError,
     ThreadEvent, ThreadFeedback, ThreadId, ThreadSummary, TokenUsageRatio,
 };
 pub use thread_store::{SerializedThread, TextThreadStore, ThreadStore};
 
-pub fn init(cx: &mut gpui::App) {
-    thread_store::init(cx);
+pub fn init(fs: Arc<dyn Fs>, cx: &mut gpui::App) {
+    thread_store::init(fs, cx);
 }
