@@ -1,13 +1,19 @@
 mod agent;
+mod db;
+mod history_store;
 mod native_agent_server;
-mod prompts;
 mod templates;
 mod thread;
+mod tool_schema;
 mod tools;
 
 #[cfg(test)]
 mod tests;
 
 pub use agent::*;
+pub use db::*;
+pub use history_store::*;
 pub use native_agent_server::NativeAgentServer;
+pub use templates::*;
 pub use thread::*;
+pub use tools::*;
