@@ -422,17 +422,15 @@ mod tests {
     use agent::MessageSegment;
     use agent::context::LoadedContext;
     use client::Client;
-    use fs::FakeFs;
+    use fs::{FakeFs, Fs};
     use gpui::AppContext;
     use gpui::TestAppContext;
     use http_client::FakeHttpClient;
     use language_model::Role;
     use project::Project;
-    use serde_json::json;
     use settings::SettingsStore;
-    use util::test::TempTree;
 
-    fn init_test(cx: &mut TestAppContext) {
+    fn init_test(fs: Arc<dyn Fs>, cx: &mut TestAppContext) {
         env_logger::try_init().ok();
         cx.update(|cx| {
             let settings_store = SettingsStore::test(cx);
@@ -443,7 +441,7 @@ mod tests {
             let http_client = FakeHttpClient::with_404_response();
             let clock = Arc::new(clock::FakeSystemClock::new());
             let client = Client::new(clock, http_client, cx);
-            agent::init(cx);
+            agent::init(fs, cx);
             agent_settings::init(cx);
             language_model::init(client, cx);
         });
@@ -451,10 +449,8 @@ mod tests {
 
     #[gpui::test]
     async fn test_retrieving_old_thread(cx: &mut TestAppContext) {
-        let tree = TempTree::new(json!({}));
-        util::paths::set_home_dir(tree.path().into());
-        init_test(cx);
         let fs = FakeFs::new(cx.executor());
+        init_test(fs.clone(), cx);
         let project = Project::test(fs, [], cx).await;
 
         // Save a thread using the old agent.
