@@ -1,4 +1,3 @@
-use std::path::Path;
 use std::sync::Arc;
 use std::sync::atomic::AtomicBool;
 
@@ -10,7 +9,7 @@ use gpui::{
 use picker::{Picker, PickerDelegate};
 use project::{PathMatchCandidateSet, ProjectPath, WorktreeId};
 use ui::{ListItem, Tooltip, prelude::*};
-use util::ResultExt as _;
+use util::{ResultExt as _, paths::PathStyle, rel_path::RelPath};
 use workspace::Workspace;
 
 use crate::context_picker::ContextPicker;
@@ -161,6 +160,8 @@ impl PickerDelegate for FileContextPickerDelegate {
         cx: &mut Context<Picker<Self>>,
     ) -> Option<Self::ListItem> {
         let FileMatch { mat, .. } = &self.matches.get(ix)?;
+        let workspace = self.workspace.upgrade()?;
+        let path_style = workspace.read(cx).path_style(cx);
 
         Some(
             ListItem::new(ix)
@@ -172,6 +173,7 @@ impl PickerDelegate for FileContextPickerDelegate {
                     &mat.path,
                     &mat.path_prefix,
                     mat.is_dir,
+                    path_style,
                     self.context_store.clone(),
                     cx,
                 )),
@@ -214,14 +216,13 @@ pub(crate) fn search_files(
 
         let file_matches = project.worktrees(cx).flat_map(|worktree| {
             let worktree = worktree.read(cx);
-            let path_prefix: Arc<str> = worktree.root_name().into();
             worktree.entries(false, 0).map(move |entry| FileMatch {
                 mat: PathMatch {
                     score: 0.,
                     positions: Vec::new(),
                     worktree_id: worktree.id().to_usize(),
                     path: entry.path.clone(),
-                    path_prefix: path_prefix.clone(),
+                    path_prefix: worktree.root_name().into(),
                     distance_to_relative_ancestor: 0,
                     is_dir: entry.is_dir(),
                 },
@@ -251,7 +252,7 @@ pub(crate) fn search_files(
             fuzzy::match_path_sets(
                 candidate_sets.as_slice(),
                 query.as_str(),
-                None,
+                &None,
                 false,
                 100,
                 &cancellation_flag,
@@ -269,51 +270,31 @@ pub(crate) fn search_files(
 }
 
 pub fn extract_file_name_and_directory(
-    path: &Path,
-    path_prefix: &str,
+    path: &RelPath,
+    path_prefix: &RelPath,
+    path_style: PathStyle,
 ) -> (SharedString, Option<SharedString>) {
-    if path == Path::new("") {
-        (
-            SharedString::from(
-                path_prefix
-                    .trim_end_matches(std::path::MAIN_SEPARATOR)
-                    .to_string(),
-            ),
-            None,
-        )
-    } else {
-        let file_name = path
-            .file_name()
-            .unwrap_or_default()
-            .to_string_lossy()
-            .to_string()
-            .into();
-
-        let mut directory = path_prefix
-            .trim_end_matches(std::path::MAIN_SEPARATOR)
-            .to_string();
-        if !directory.ends_with('/') {
-            directory.push('/');
-        }
-        if let Some(parent) = path.parent().filter(|parent| parent != &Path::new("")) {
-            directory.push_str(&parent.to_string_lossy());
-            directory.push('/');
-        }
-
-        (file_name, Some(directory.into()))
-    }
+    let full_path = path_prefix.join(path);
+    let file_name = full_path.file_name().unwrap_or_default();
+    let display_path = full_path.display(path_style);
+    let (directory, file_name) = display_path.split_at(display_path.len() - file_name.len());
+    (
+        file_name.to_string().into(),
+        Some(SharedString::new(directory)).filter(|dir| !dir.is_empty()),
+    )
 }
 
 pub fn render_file_context_entry(
     id: ElementId,
     worktree_id: WorktreeId,
-    path: &Arc<Path>,
-    path_prefix: &Arc<str>,
+    path: &Arc<RelPath>,
+    path_prefix: &Arc<RelPath>,
     is_directory: bool,
+    path_style: PathStyle,
     context_store: WeakEntity<ContextStore>,
     cx: &App,
 ) -> Stateful<Div> {
-    let (file_name, directory) = extract_file_name_and_directory(path, path_prefix);
+    let (file_name, directory) = extract_file_name_and_directory(path, path_prefix, path_style);
 
     let added = context_store.upgrade().and_then(|context_store| {
         let project_path = ProjectPath {
@@ -330,9 +311,9 @@ pub fn render_file_context_entry(
     });
 
     let file_icon = if is_directory {
-        FileIcons::get_folder_icon(false, path, cx)
+        FileIcons::get_folder_icon(false, path.as_std_path(), cx)
     } else {
-        FileIcons::get_icon(path, cx)
+        FileIcons::get_icon(path.as_std_path(), cx)
     }
     .map(Icon::from_path)
     .unwrap_or_else(|| Icon::new(IconName::File));
