@@ -160,7 +160,7 @@ mod tests {
                 &mut parser,
                 &mut rng
             ),
-            // This output is marlformed, so we're doing our best effort
+            // This output is malformed, so we're doing our best effort
             "Hello world\n```\n\nThe end\n".to_string()
         );
     }
@@ -182,7 +182,7 @@ mod tests {
                 &mut parser,
                 &mut rng
             ),
-            // This output is marlformed, so we're doing our best effort
+            // This output is malformed, so we're doing our best effort
             "```\nHello world\n```\n".to_string()
         );
     }
@@ -204,7 +204,7 @@ mod tests {
     }
 
     fn parse_random_chunks(input: &str, parser: &mut CreateFileParser, rng: &mut StdRng) -> String {
-        let chunk_count = rng.gen_range(1..=cmp::min(input.len(), 50));
+        let chunk_count = rng.random_range(1..=cmp::min(input.len(), 50));
         let mut chunk_indices = (0..input.len()).choose_multiple(rng, chunk_count);
         chunk_indices.sort();
         chunk_indices.push(input.len());
