@@ -104,7 +104,7 @@ mod tests {
     async fn test_to_absolute_path(cx: &mut TestAppContext) {
         init_test(cx);
         let temp_dir = TempDir::new().expect("Failed to create temp directory");
-        let temp_path = temp_dir.path().to_string_lossy().to_string();
+        let temp_path = temp_dir.path().to_string_lossy().into_owned();
 
         let fs = FakeFs::new(cx.executor());
         fs.insert_tree(
